@@ -32,7 +32,9 @@ def model_reader(model_name, model_path):
                 isFound = False   
             if "class %s" % model_name in line or (isFound and line != ""):
                 if "class %s" % model_name not in line and "=" in line:
-                    fields.append(line.split("=")[0].strip())
+                    line_split = line.split("=")
+                    if "db.Column" in line_split[1] :
+                        fields.append(line_split[0].strip())
                 isFound = True
     return fields
 
